// Persistence of Vision Ray Tracer Scene Description File
// File: ?.pov
// Vers: 3.5RC6
// Desc: Grids in noise_generators
// Date: June 2002
// Auth: Philippe Debar
// +a0.2 +h400 +w400 +kfi0 +kff5 +ki0 +kf5 +sf0 +ef5

#version 3.5;

// clock=0 -> noise_generator 3, pure
// clock=1 -> noise_generator 3, difference
// clock=2 -> noise_generator 1, difference
// clock=3 -> noise_generator 2, difference
// clock=4 -> noise_generator 3, difference, sphere
// clock=5 -> noise_generator 3, pure, sphere

global_settings {
  assumed_gamma 1.0
  #switch(clock)
    #case(2)
      noise_generator 1 // old 3.1g plateaud noise
    #break
    #case(3)
      noise_generator 2 // fixed version of 3.1 noise
    #break
    #else
      noise_generator 3 // New 3.5 perlin noise
  #end
}

#default{texture{pigment{color rgb 1 } finish{specular .25 ambient 0}}} 
#background{color rgb .45}

// ----------------------------------------

camera {
  location  < 0, 0, -20>
  direction 3*z
  right     x*image_width/image_height
  look_at   < 0, 0, 0>
}


light_source { -100*z  color rgb 1.25 rotate <50,60,0> }
light_source { -100*z  color rgb <0,0,.33> rotate <-20,-80,0> }

// ----------------------------------------

#include "functions.inc"
  


#declare f_noise3d_Diff=
  function(x,y,z){
  #local epsi=1e-5;
  #local mult=1e4;
  +(f_noise3d(x,y,z)-f_noise3d(x-epsi,y-epsi,z-epsi))*mult
   };


isosurface {
  #switch(clock)
    #case(0)
      function {-z+f_noise3d(x,y,z)}
    #break
    #case(1)
      function {-z+f_noise3d_Diff(x,y,z)}
    #break
    #case(2)
      function {-z+f_noise3d_Diff(x,y,z)}
    #break
    #case(3)
      function {-z+f_noise3d_Diff(x,y,z)}
    #break
    #case(4)
      function {f_sphere(x,y,z-2.5,2.7)+f_noise3d_Diff(x,y,z)}
    #break
    #case(5)
      function {f_sphere(x,y,z-2.5,3)+f_noise3d(x,y,z)/2}
    #break
  #end
  contained_by { box { -3, 3 } }
  accuracy 0.001
  max_gradient 2
}


sphere {<0,0,0>, .05 texture{pigment{color red 1} finish{specular .5}}}
sphere {<1,0,0>, .05 texture{pigment{color red 1} finish{specular .5}}}
sphere {<1,1,0>, .05 texture{pigment{color red 1} finish{specular .5}}}
sphere {<0,1,0>, .05 texture{pigment{color red 1} finish{specular .5}}}

text {
  ttf
  "crystal.ttf",
  #switch(clock)
    #case(0)
      "f_noise3d, noise_generator 3"
    #break
    #case(1)
      "f_noise3d, difference, noise_generator 3"
    #break
    #case(2)
      "f_noise3d, difference, noise_generator 1"
    #break
    #case(3)
      "f_noise3d, difference, noise_generator 2"
    #break
    #case(4)
      "f_noise3d, difference, n_gen 3, check z<>0"
    #break
    #case(5)
      "f_noise3d, n_gen 3, check z<>0"
    #break
  #end
  .05,
  0
  scale .25
  translate <-3.2,-3.2,-.5>
  texture{pigment{rgb <0,.1,.7>} finish{diffuse 0 specular 0 ambient 1}}
}

